==> haskell-binary-tagged-0.1.4.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.0
id: binary-tagged-0.1.4.0-KAH78hx7nzZGvaapk5zrAx
key: binary-tagged-0.1.4.0-KAH78hx7nzZGvaapk5zrAx
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
abi: 6fc793b95f588a4bdbf2daa3cd7884ec
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/binary-tagged-0.1.4.0
hs-libraries: HSbinary-tagged-0.1.4.0-KAH78hx7nzZGvaapk5zrAx
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    aeson-0.11.2.0-KYo3VjEYbuTH5av5CAe0oK array-0.5.1.1 base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1 containers-0.5.7.1
    generics-sop-0.2.1.0-CBmuKl000aDETY5eYHsItd
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    scientific-0.3.4.6-5cHpJJUGtwpEY8OVHMLxLn
    semigroups-0.18.1-ESRONlmV7qgKe0wL9ZoBKD
    tagged-0.8.4-9gtrXrOYlY5BIFTjUM7KTh
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.1.4.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.0
id: binary-tagged-0.1.4.0-JE2T00MAZPI2gaM4UW3f9D
key: binary-tagged-0.1.4.0-JE2T00MAZPI2gaM4UW3f9D
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
abi: 0bb43341ca277d0bafe50af6c0bf2153
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/binary-tagged-0.1.4.0
hs-libraries: HSbinary-tagged-0.1.4.0-JE2T00MAZPI2gaM4UW3f9D
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    aeson-0.11.2.0-FbOoMAnyGWNAFaN63GUEkg array-0.5.1.1 base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1 containers-0.5.7.1
    generics-sop-0.2.1.0-CBmuKl000aDETY5eYHsItd
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    scientific-0.3.4.7-5pvfIBiHUcSGJtkaWTYnEJ
    semigroups-0.18.1-ESRONlmV7qgKe0wL9ZoBKD
    tagged-0.8.4-9gtrXrOYlY5BIFTjUM7KTh
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
